espressodb.notifications
==================================================
**Module**: :mod:`espressodb.notifications`


.. autosummary::
   espressodb.notifications.models
   espressodb.notifications.views
   espressodb.notifications.urls
   espressodb.notifications.templatetags

.. automodule:: espressodb.notifications

----

.. autofunction:: espressodb.notifications.get_notifier

.. toctree::
   :glob:
   :hidden:

   *
   templatetags/index
